import pkg_resources

from zope.interface import implements

from karl.bootstrap.interfaces import IInitialOfficeData
from karl.bootstrap.data import DefaultInitialData

from repoze.bfg.security import Allow

from karl.security.policy import ADMINISTRATOR_PERMS
from karl.security.policy import GUEST_PERMS
from karl.security.policy import NO_INHERIT

sample_feature = """\
<div>
  <div class="teaser">
    <a href="http://campaignforeducation.org/en/why-education-for-all/" target="_blank">
      <img src="/static/images/teaser.png" />
    </a>
  </div>
  <div class="visualClear"></div>
  <div class="featureLinks">
    <p>
     <a href="http://campaignforeducation.org/en/why-education-for-all/" target="_blank">
        Read more on Campaingforeduction.org
        </a>
    </p>
  </div>
</div>
"""

navmenu_template = u"""\
<div>
  <div class="menu">
    <h3>About CSEF</h3>
    <ul class="nav">
      <li>
        <a href="#" target="" title="">About CSEF</a>
      </li>
      <li>
        <a href="/people" target="" title="">Network Directory</a>
      </li>  
    </ul>
  </div>

  
  <div class="menu">
     <h3>KARL Resources</h3>
     <ul class="nav">
       <li class="nav">
         <a href="/communities/about-karl" target="" title="About KARL">About KARL Community</a>
       </li>
       <li class="nav">
         <a href="/communities/about-karl/wiki/karl-user-manual" target="" title="User Manual">User Manual</a>
       </li>
       <li class="nav">
         <a href="/communities/about-karl/wiki/frequently-asked-questions/" target="" title="FAQ">FAQ's</a>
       </li>
       <li class="nav">
         <a href="/communities/karl-feedback/" target="" title="KARL Feedback">KARL Feedback Community</a>
       </li>
     </ul>
   </div>
</div>
"""

class SampleInitialData(DefaultInitialData):
    users_and_groups = [
        ('admin', 'Ad','Min','admin@example.com',
         ('group.KarlAdmin', 'group.KarlUserAdmin', 'group.KarlStaff')),
        ('affiliate', 'Aff', 'Illiate', 'affiliate@example.com',
         ('group.KarlAffiliate',)),
        ('staff1','Staff','One','staff1@example.com',
         ('group.KarlStaff',)),
        ('staff2','Staff','Two','staff2@example.com',
         ('group.KarlStaff',)),
        ('affiliate1','Affiliate','One','affiliate1@example.com',
         ('groups.KarlAffiliate',)),
        ('affiliate2','Affiliate','Two','affiliate2@example.com',
         ('groups.KarlAffiliate',))
       
    ]

sample_forums = [
    {'id': 'csef-events', 'title': 'CSEF Events' },
    {'id': 'csef-news', 'title': 'CSEF News' },
    {'id': 'csef-personals', 'title': 'CSEF Personals' },
    ]

class SampleInitialOfficeData(object):
    implements(IInitialOfficeData)

    title = 'CSEF'

    offices = [
        {'id': 'csef',
         'title': 'CSEF Head office',
         'address': '26 Baker Street',
         'city': 'Rosebank',
         'state': 'Gauteng',
         'country': 'South Africa',
         'zipcode': '2132',
         'telephone': '0027114474111',
         'middle_portlets': ['/offices/files/network-news','/offices/files/network-events'],
         'right_portlets': ['/offices/csef/forums/csef-events','/offices/csef/forums/csef-news','/offices/csef/forums/csef-personals'],
         'forums': sample_forums,
         'navmenu': navmenu_template % {
             'org': 'csfe',
             'org_upper': 'CSEF Head Office'},
         },
    ]

    offices_acl = [
        (Allow, 'group.KarlAdmin', ADMINISTRATOR_PERMS),
        (Allow, 'group.KarlStaff', GUEST_PERMS),
        NO_INHERIT,
    ]

    feature = sample_feature


    @property
    def pages(self):
        return [
            ('terms_and_conditions', 'Terms and Conditions',
             pkg_resources.resource_stream(
                 __name__, 'pages/terms_and_conditions.html').read()),
             ('privacy_statement', 'Privacy Statement',
              pkg_resources.resource_stream(
                  __name__, 'pages/privacy_statement.html').read()),
        ]
